      subroutine convStdtime(year, jday, secsoday, time)
      
C***********************************************************************
C* CONVTIME     Converts time in year,julian date and seconds of day to*
C*              Gprof time format YYMMDDHHMMSS.                        *
C*                                                                     *
C* Called By:   INGEST_HDF_YE                                          *
C*                                                                     *
C* Calls:       <none>                                                 *
C*                                                                     *
C* Input Parameters:                                                   *
C*                                                                     *
C*  year     	INT     year					       *
C*  jday	INT     julian day                		       *
C*  secsoday    REAL    time in seconds of day beginning at the start  *
C*                      of the current day                             *
C*                                                                     *
C* Output Parameters:                                                  *
C*                                                                     *
C*   time       INT     Gprof time format YYMMDDHHMMSS                 *
C*                                                                     *
C**                                                                    *
C* Log:                                                                *
C* Y. Hong      2/98    Modified CONVTIME.f, written by D.Bolvin/SSAI  *
C*                      for converting julian date and seconds of day  *
C*                      to seconds since 1/1/87, to a subroutine       *
C*                      which outputs gprof time format                *
C* E. Nelkin   11/11    Adjust fields if input seconds were in range   *
C*                      86399.5-86400.0, which previously returned     *
C*                      HH:MM:SS as 24:00:00                           *
C***********************************************************************
C
        IMPLICIT        NONE
c
        INTEGER*2       sec_per_min
        INTEGER*4       sec_per_hour
        parameter       (sec_per_hour = 3600, sec_per_min = 60)
C
C***********************************************************************
C       Declaration of subroutine input/output arguments.
C
        INTEGER*2       year, jday
        REAL*4          secsoday
        INTEGER*2       time(6), sec

        time(1) = year
C
C***********************************************************************
C       Compute the hours field here, because an input seconds value
C       in the range 86399.5-86400.0 will yield an hour value of 24,
C       which requires incrementing jday before calling jday2mmdd.
C
        time(4) = nint(secsoday) / sec_per_hour
C
        if ( time(4) .EQ. 24 ) then
C
           time(4) = 0
           time(5) = 0
           time(6) = 0
C
           jday = jday + 1
C
           if ( jday .GT. 365 ) THEN
C
              if ( (MOD(year, 4) .EQ. 0 .AND. MOD(year, 100) .NE. 0)
     &         .OR. MOD(year, 400) .EQ. 0 ) then
C
                 if ( jday .GT. 366 ) then
                    jday = 1
                    year = year + 1
                 endif
              else
                 jday = 1
                 year = year + 1
              endif            
           endif
           call jday2mmdd(year, jday, time(2), time(3))
           time(1) = year
           RETURN
        endif
C
C***********************************************************************
C       Convert the jul. date to month and day of month
        call jday2mmdd(year, jday, time(2), time(3))
C
C***********************************************************************
C       Convert the second of day to HH MM SS
        ! hours
CC      time(4) = nint(secsoday) / sec_per_hour
c
c This was a bug, mod must have same type
c
        sec = mod(nint(secsoday), sec_per_hour)
c     
        ! minutes
        time(5) = sec / sec_per_min
CC      if(time(5).lt.0) write(*,*) 5,time(5),sec,secsoday

        sec = mod(sec, sec_per_min)

        ! seconds
        time(6) = sec

CC      if(time(6).lt.0) write(*,*) 6,time(6)
C
        RETURN
        END
      


c*************************************************************************
      subroutine jday2mmdd(iyear, jday, month, day)
c*************************************************************************
        
      implicit        none
        
      integer*2       iyear, jday, month, day
      integer*2       jd2mon(365), jd2day(365)                ! non-leap year
      integer*2       jd2monL(366), jd2dayL(366)              ! leap year
        
      data jd2mon/1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
     &            1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
     &            1, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
     &            2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 3,
     &            3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
     &            3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
     &            4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
     &            4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 
     &            5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
     &            5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
     &            5, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 
     &            6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 
     &            6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 
     &            7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 
     &            7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 
     &            8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8,
     &            8, 8, 8, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 
     &            9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9,  
     &            9, 9, 9,10,10,10,10,10,10,10,10,10,10,10,10,
     &           10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,
     &           10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,
     &           11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,
     &           11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,
     &           12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,
     &           12,12,12,12,12/ 

      data jd2day/1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,12,13,14,15,
     &           16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,
     &           31, 1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,12,13,14,
     &           15,16,17,18,19,20,21,22,23,24,25,26,27,28, 1,
     &            2, 3, 4, 5, 6, 7, 8, 9,10,11,12,13,14,15,16,
     &           17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,
     &            1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,12,13,14,15,
     &           16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,
     &            1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,12,13,14,15,
     &           16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,
     &           31, 1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,12,13,14,
     &           15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,
     &           30, 1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,12,13,14,
     &           15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,
     &           30,31, 1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,12,13,
     &           14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,
     &           29,30,31, 1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,12,
     &           13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,
     &           28,29,30, 1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,12,
     &           13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,
     &           28,29,30,31, 1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,
     &           12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,
     &           27,28,29,30, 1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,
     &           12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,
     &           27,28,29,30,31/

      data jd2monL/1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
     &             1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
     &             1, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
     &             2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
     &             3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
     &             3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
     &             3, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
     &             4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 
     &             4, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
     &             5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
     &             5, 5, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 
     &             6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 
     &             6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 
     &             7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 
     &             7, 7, 7, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 
     &             8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8,
     &             8, 8, 8, 8, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 
     &             9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9,  
     &             9, 9, 9, 9,10,10,10,10,10,10,10,10,10,10,10,
     &            10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,
     &            10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,
     &            11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,
     &            11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,
     &            12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,
     &            12,12,12,12,12,12/ 

      data jd2dayL/1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,12,13,14,15,
     &            16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,
     &            31, 1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,12,13,14,
     &            15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,
     &             1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,12,13,14,15,
     &            16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,
     &            31, 1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,12,13,14,
     &            15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,
     &            30, 1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,12,13,14,
     &            15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,
     &            30,31, 1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,12,13,
     &            14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,
     &            29,30, 1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,12,13,
     &            14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,
     &            29,30,31, 1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,12,
     &            13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,
     &            28,29,30,31, 1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,
     &            12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,
     &            27,28,29,30, 1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,
     &            12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,
     &            27,28,29,30,31, 1, 2, 3, 4, 5, 6, 7, 8, 9,10,
     &            11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,
     &            26,27,28,29,30, 1, 2, 3, 4, 5, 6, 7, 8, 9,10,
     &            11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,
     &            26,27,28,29,30,31/

        if((mod(iyear, 4) .eq. 0 .and. mod(iyear, 100) .ne. 0) 
     &     .or. mod(iyear, 400) .eq. 0)then                     ! leap year
           month = jd2monL(jday)
           day = jd2dayL(jday)
        
        else                                                    ! non-leap year
           month = jd2mon(jday)
           day = jd2day(jday)
        endif

        return
        end
