	SUBROUTINE extract_ssmis_tdrr(cjobid,filename, syear, sjday, 
     &             eyear, ejday, jdate, btime, sat_name,
     &		   a19v, a19h, a22v, a37v, a37h, a91v, a91h,  
     &    	   alat1, alon1, alat2, alon2, alat3, alon3, 
     &             scanlines,hrs,mns,sfc_img,sfc_env,coeff_19v,
     &             coeff_19h,coeff_22v,coeff_37v,coeff_37h,coeff_91v,
     &             coeff_91h,do_debug,iret)
C
C 5/10/2011 EJN - Change "btime" to real*4 (was integer*4) for
C                 compatibility with select_unique.
C 5/10/2011 EJN - Add jdate array to argument list
C10/12/2011 EJN - Add sfc_img, sfc_env to argument list and read them in
C11/ 2/2011 EJN - Pass in do_debug, pass back iret, to handle errors
C11/ 2/2011 EJN - Pass in coeff arrays, read in main program and passed
C                 here via subroutine retrieval
C 9/27/2012 EJN - Non-PPS version for Bob Joyce
C
      	implicit none
        include 'parameters.inc'

	!==== Input parameters==================================================

c       character*93	filename 		    !input tdrr file name
        character*65	filename 		    !input tdrr file name
CC      character*256   coeff_file                  !bias coeff file
        character*256   cjobid
	
	!==== Output parameters=================================================
        integer         HEADER_SIZE                 ! header size  (SSMIS)
        parameter       (HEADER_SIZE=40)

	integer*2	syear		            !Starting year
	integer*2	sjday		            !Starting julian day
	integer*2	year		            !year
	integer*2	jday		            !julian day of the year
	integer*4       jdate(MAX_SCANS)	    !packed Julian date array (YYYYDDD)
        integer*2       eyear                       !Ending year
        integer*2       ejday                       !Ending julian day
	integer*2	hrs		            !Starting hour
	integer*2	mns		            !Starting minute
        integer*4       timetemp

        real*4          btime(MAX_SCANS)            !Time for each scan starting
						    !from current day in seconds
	real*4 		a19v(NPIX/2,MAX_SCANS)       !array 19V data in kelvin
	real*4 		a19h(NPIX/2,MAX_SCANS)       !array 19H data in kelvin
	real*4 		a22v(NPIX/2,MAX_SCANS)       !array 22V data in kelvin
	real*4 		a37v(NPIX/2,MAX_SCANS)       !array 37V data in kelvin
	real*4 		a37h(NPIX/2,MAX_SCANS)       !array 37H data in kelvin
	
	real*4 		a91v(NPIX,MAX_SCANS)       !array 91V data in kelvin
	real*4 		a91h(NPIX,MAX_SCANS)       !array 91h data in kelvin
	
        real*4          coeff_19v(NPIX/2)       !array 19V data in kelvin
        real*4          coeff_19h(NPIX/2)       !array 19H data in kelvin
        real*4          coeff_22v(NPIX/2)       !array 22V data in kelvin
        real*4          coeff_37v(NPIX/2)       !array 37V data in kelvin
        real*4          coeff_37h(NPIX/2)       !array 37H data in kelvin
        
        real*4          coeff_91v(NPIX)         !array 91V data in kelvin
        real*4          coeff_91h(NPIX)         !array 91h data in kelvin
CC      real*4          coeff_189(NPIX)         !array 189 data in kelvin
CC      real*4          coeff_186(NPIX)         !array 186 data in kelvin
CC      real*4          coeff_184(NPIX)         !array 184 data in kelvin
CC      real*4          coeff_150(NPIX)         !array 150 data in kelvin
 
	integer*2	sfc_img(NPIX,MAX_SCANS) ! sfc tag for imaging

	real*4 		alat1(NPIX,MAX_SCANS)      !array of latitude in degree
	real*4 		alon1(NPIX,MAX_SCANS)      !array of longitude in degree

	integer*2	sfc_env(NPIX/2,MAX_SCANS)  ! sfc tag for environmental
	real*4 		alat2(NPIX/2,MAX_SCANS)      !array of latitude in degree
	real*4 		alon2(NPIX/2,MAX_SCANS)      !array of longitude in degree

	real*4 		alat3(NPIX/2,MAX_SCANS)      !array of latitude in degree
	real*4 		alon3(NPIX/2,MAX_SCANS)      !array of longitude in degree
	
	integer*4 	scanlines      		    !scanlines in this file
        integer*4       iret
        logical         do_debug
	
	!==== internal variables================================================
	character*1	dat(SCAN_LENGTH),  head(HEADER_SIZE)
	integer*2	idat(SCAN_LENGTH),ihead(HEADER_SIZE) 
	integer 	iline, dd, i, j, beam, k
	
	integer*2 	d19v, d19h, d22v, d37v, d37h
	integer*2 	d91v1,d91v2,d91v3,d91v4,d91h1,d91h2,d91h3,d91h4
	
	integer*4	kk,rec_kk
	
	integer*2       ilat,ilon,chaux1, chaux2, chaux3

        character*3     sat_name
        character*60    trash


	!==== fill the arrays ====================
	!For Tb, latitude, and longitude, the fill value is -999.9.  
	!For surface type, the fill value is -1.  
	!For time, the fill value is -999

	do j=1, MAX_SCANS

	   btime(j)=-999.
   
	   do i=1,NPIX/2
	     alat2(i,j)=-999.9
	     alat2(i,j)=-999.9
	     alat3(i,j)=-999.9
	     alat3(i,j)=-999.9
             alon2(i,j)=-999.9
             alon2(i,j)=-999.9
             alon3(i,j)=-999.9
             alon3(i,j)=-999.9
	     sfc_env(i,j)=-999.9

	     a19v(i,j)=-999.9
	     a19h(i,j)=-999.9
	     a22v(i,j)=-999.9
	     a37v(i,j)=-999.9
	     a37h(i,j)=-999.9
	   enddo
     
	   do i=1,NPIX
	     alat1(i,j)=-999.9
	     alat1(i,j)=-999.9
             alon1(i,j)=-999.9
             alon1(i,j)=-999.9
	     sfc_img(i,j)=-999.9

	     a91v(i,j)=-999.9
	     a91h(i,j)=-999.9
	   enddo
	enddo

CC      !==== Read bias correction coeff data for SSMIS TDR file ======
CC      ! ASCII file, pretty fast...

CC      coeff_file='ssmis_scan_correction_files/ssmis_'//sat_name//
CC   &             '_env_scan_correction_coefficients'
CC      open(30,file=coeff_file, status='old')
CC      do k=1,93
CC      if (k.le.3) then
CC      read(30, '(A60)') trash
CC      else
CC      read(30,'(i4,5(1x,f8.6))')beam, coeff_19h(k-3), coeff_19v(k-3),
CC   &      coeff_22v(k-3), coeff_37h(k-3),coeff_37v(k-3)
CC      endif
CC      enddo
CC      close (30)

CC      coeff_file='ssmis_scan_correction_files/ssmis_'//sat_name//
CC   &             '_img_scan_correction_coefficients'
CC      open(30,file=coeff_file, status='old')
CC      do k=1,183
CC      if (k.le.3) then
CC      read(30, '(A60)') trash
CC      else
CC      read(30,'(i4,6(1x,f8.6))')beam, coeff_150(k-3), coeff_189(k-3),
CC   &      coeff_186(k-3), coeff_184(k-3),coeff_91v(k-3),
CC   &      coeff_91h(k-3)
CC      endif
CC      enddo
CC      close (30)


	!==== Read data from SSMIS TDR file ======
	! This is relatively slow - the file is written
	! in an inconvenient form, so it has to be read 
	! with each byte as a record... slow!

        iret = 0

        write (6,'('' input '',a84)') filename

	open(20, file=filename, form='unformatted', access = 'direct',
     &       recl=1, err=1018)

	do kk=1,HEADER_SIZE
        read(20,rec=kk,err=1019) head(kk)
	   ihead(kk) = ichar(head(kk))
	enddo


	scanlines = ihead(19)*256 + ihead(20)
	year      = ihead(9)*256*256*256 + ihead(10)*256*256 +
     &              ihead(11)*256 + ihead(12)
	jday      = ihead(13)*256 + ihead(14)
	hrs       = ihead(15)
	mns       = ihead(16)

C	write(*,*)'date = ', year, jday, hrs, mns
C	write(*,*)'scanlines  = ',scanlines
	
	if ( scanlines .gt. MAX_SCANS/2 ) then 
          IF (do_debug) WRITE(*,*) 'Error: scanlines > MAX_SCANS/2 ',
     &       'in extract-ssmis-tdrr; increase MAX_SCANS in ',
     &       'parameters.inc'
          iret = 1
          RETURN
	endif
C
	do iline=1,scanlines
	  do kk=1,SCAN_LENGTH
	     rec_kk=((iline-1)*SCAN_LENGTH+HEADER_SIZE)+kk
	     read(20,rec=rec_kk,err=1019) dat(kk)
	     idat(kk)=ichar(dat(kk))
	  enddo
C
	  !seconds starting from this current day, should be divided by 10000 
	  year =        idat(1)*256*256*256+
     &   		idat(2)*256*256+
     &			idat(3)*256+
     &			idat(4)
	  jday =        idat(5)*256+idat(6)
	  jdate(iline) = year*1000 + jday
	  timetemp=	idat(13)*256*256*256+
     &   		idat(14)*256*256+
     &			idat(15)*256+
     &			idat(16)
C
	  btime(iline) = float(timetemp)/1000.
C
          if (iline.eq.1) then
	     syear = year
	     sjday = jday
	  endif

          if (iline.eq.scanlines) then
	     eyear = year
	     ejday = jday
	  endif
	  
	  do i=1,NPIX    	   !imager scan

	     dd=24*(i-1)           !each cell has 24 bytes
	    
	    !latitude and longtitude in 91 GHz

	    sfc_img(i,iline)=idat(103+dd)
	    ilat=(idat(113+dd)*256+idat(114+dd))
	    ilon=(idat(115+dd)*256+idat(116+dd))
	    alat1(i,iline)=ilat*0.01
	    alon1(i,iline)=ilon*0.01
 	    
	    !91Ghz channel data
	    chaux1=(idat(117+dd)*256+idat(118+dd))
	    chaux2=(idat(119+dd)*256+idat(120+dd))
            a91v(i,iline)=(chaux1*0.01+273.15)*coeff_91v(i)
            a91h(i,iline)=(chaux2*0.01+273.15)*coeff_91h(i)
      

	  end do     	           !imager scan

	  do i=1,NPIX/2    	   !environmental scan

	     dd=20*(i-1)           !each cell has 20 bytes
	    
	    !latitude and longtitude in 37 GHz
	    ilat=(idat(4429+dd)*256+idat(4430+dd))
	    ilon=(idat(4431+dd)*256+idat(4432+dd))
	    alat2(i,iline)=ilat*0.01
	    alon2(i,iline)=ilon*0.01
 	    
	    !37Ghz channel data
	    chaux1=(idat(4433+dd)*256+idat(4434+dd))
	    chaux2=(idat(4435+dd)*256+idat(4436+dd))
            a37h(i,iline)=(chaux1*0.01+273.15)*coeff_37h(i)
            a37v(i,iline)=(chaux2*0.01+273.15)*coeff_37v(i)

	    !latitude and longtitude in 19-22 GHz
	    sfc_env(i,iline)=idat(4422+dd)
	    ilat=(idat(4417+dd)*256+idat(4418+dd))
	    ilon=(idat(4419+dd)*256+idat(4420+dd))
	    alat3(i,iline)=ilat*0.01
	    alon3(i,iline)=ilon*0.01
 	    
	    !19-22 Ghz channel data
	    chaux1=(idat(4423+dd)*256+idat(4424+dd))
	    chaux2=(idat(4425+dd)*256+idat(4426+dd))
	    chaux3=(idat(4427+dd)*256+idat(4428+dd))
            a19h(i,iline)=(chaux1*0.01+273.15)*coeff_19h(i)
            a19v(i,iline)=(chaux2*0.01+273.15)*coeff_19v(i)
            a22v(i,iline)=(chaux3*0.01+273.15)*coeff_22v(i)
	    
	  end do        !environmental scan
	  
	enddo		! end of loop iline
	
	close(20,err=1020)
	

	


	return

 1018   IF (do_debug) WRITE(*,*) 'Error opening CLASS SSMIS TDR file!'
        iret = 1
        return
 1019   IF (do_debug) WRITE(*,*) 'Error reading CLASS SSMIS TDR file!'
        iret = 1
        return
 1020   IF (do_debug) WRITE(*,*) 'Error closing CLASS SSMIS TDR file!'
        iret = 1
	return
	end
