
      subroutine get_clear_tbs(t19v,t19h,t23v,
     &             t37v,t37h,t85v,t85h,sst,
     &             wv,u, status)


* This is a semi-empirical, preliminary algorithm for estimating clear-sky
* brightness temperature for TMI channels.  If estimate cannot be made, 
* returned values are set to -100.
*
* For diagnostic purposes, the nominal retrieved wind speed U and water vapor
* WV are also returned.  These should look "reasonable" but are not calibrated
* values.
*
* - G. Petty,  Nov. 2000

* put the following parameters to include file .. chiu
*
* ista(1) =   0: wv and u are both okay
*     (2) = -10: wv is okay, but no calculations on u due to contamination.
*     (3) = -51: no calculations for both wv and u due to contamination.

* coefficients of regression and range of wv and u are set up in include file.

* 06/02 Removed theta since it is not used

      implicit none           ! Remove at own risk!

      include   'clear_tb_param.inc'
      integer*2 status  !chiu
      real      t19h, t19v, t23v, t37h, t37v, t85h, t85v
      real      sst, wv, u
      real      alt19v, alt23v
      real      anomlt19v

      wv = -100.0
      u = -100.0
      status = ista3

*     if (t10h .gt. 100.0) return
*     if (t19h .gt. 170.0) return
      if (t19h .gt. 207.0) return
*     if (t37h .gt. 180.0) return
      if (t19v .gt. ta - 5.0) return
      if (t23v .gt. ta - 5.0) return
      if (sst .lt. 270.0 .or. sst .gt. 310.0) return
      

c      alt19v = alog(ta-5.0-t19v)
c      alt23v = alog(ta-5.0-t23v)
      alt19v = alog(ta-t19v)
      alt23v = alog(ta-t23v)

* this variable is an ad hoc proxy for column water vapor
cpc
      status = ista1
      wv = 143.3*alt19v - 128.0*alt23v - 73.0
      wv = wv*0.1
      wv = wv*1.017
c      wv = 73.94*alt19v - 77.06*alt23v - 13.56
c      if (wv.gt.rmaxwv) wv= rmaxwv
      if (wv.lt.rminwv) wv= rminwv

      status = ista2
      if (t37h .gt. 210.0) return 

* correct all brightness temperatures to 'zero' water vapor 
* 
*     anomlt19v = alt19v - wv*wvcor(3)
      anomlt19v = alt19v - wv*wvcor(2)

* ad hoc wind speed estimate

      status = ista1
*      u = -243.0*anomlt10h + 71.3*anomlt19v + 962.0
      u=147.90+1.0969*t19v-0.4555*t23v-1.7600*t37v+0.7860*t37h
      u=u*0.93
c      if (u.gt.rmaxu) u = rmaxu
      if (u.lt.rminu) u = rminu

* Note that we currently don't use SST or theta
* expected effect is fairly small but should be quantified
* eventually

      return
      end

