      ! ================================================================
      ! Input: input_file (TDRR.S7.D03099.S2328.E0120.B4150506.NS, etc)
      ! ================================================================
      subroutine retrieval(cjobid, input_file, l_if, iunit_t,
     &                     outpath_g, coeff_19v, coeff_19h, coeff_22v,
     &                     coeff_37v, coeff_37h, coeff_91v, coeff_91h,
     &                     add_oce, add_lnd, nsec0, nsec1, sat_name,
     &                     do_debug)
C
C This is a modified version of GPROF V7 (for SSMI)
C  SSMIS data is ingested and extracted and the 91GHz channel is matched
C  to the 85GHz channel.  After this conversion, the input is treated as
C  though it came from an SSMI.
C
C  3/2004 EJN - TRMM Version 6 (SSM/I Version 6.5S)
C 11/2008 Sapiano and Vila - ingest, extract and geolocate for SSMIS,
C                     +correction for 91GHz
C  5/2011 EJN - Change "atime" to real*4 (was integer*4) for
C               compatibility with select_unique
C  5/2011 EJN - Add "jdate" array to extract-ssmi-tdrr argument list
C  5/2011 EJN - Change "if (nfound .LT. nread)" to "if (nfound .LE.
C               nread)" when setting nwork, for consistency with change
C               made to ingest-ssmis-tdrr.f that handles last scan
C  5/2011 EJN - Remove irec from argument list of ingest_ssmis_tdrr
C  5/2011 EJN - Fix bug; convert_ssmis_91GHz should receive orig_lat,
C               orig_lon instead of as-yet-undefined lat, lon
C  5/2011 EJN - Change array dimensions on a19h, a19v, a22v, a37h,
C               a37v, alat2, alon2, alat3, alon3 for consistency with
C               extract and ingest subroutines
C  5/2011 EJN - For output_quarterdeg, split up output into multiple
C               gridded files if input file laps itself
C  6/2011 EJN - Added 1 x 1-degree gridded output option
C 10/2011 EJN - Added sfc_img, sfc_env surface tags
C 10/2011 EJN - Pass in iunit_t instead of timefile
C 10/2011 EJN - Add outpath_g, the directory for writing output files
C 10/2011 EJN - Pass in cjobid, needed in select_unique.F
C 10/2011 EJN - Moved do_debug to command line
C 10/2011 EJN - Pass cjobid to read_dbase, for error conditions
C 11/2011 EJN - Add error checks for ST_LSTR; pass in l_if, iunit_g;
C               write entry to granule_list_file
C 11/2011 EJN - Pass cjobid to extract-ssmis-tdrr for error checks
C 11/2011 EJN - Pass in coeff arrays and pass to extract-ssmis-tdrr
C 11/2011 EJN - Pass in add_oce, add_lnd arrays and pass to
C               ingest-ssmis-tdrr
C 11/2011 EJN - Pass in nsec0, nsec1 and use to define jstrt, jstop
C 11/2011 EJN - Changed qualctrl argument from satname to sat_name
C 11/2011 EJN - Pass in sat_name, and pass along to MK_ONAME
C 11/2011 EJN - Re-institute saving database contents and invoke
C               read_dbase only the first time retrieval is called
C 11/2011 EJN - Return without processing if istrt = istop
C 11/2011 EJN - Pass cjobid, do_debug to ingest-ssmis-tdrr and
C               surface-db93-petty
C  9/2012 EJN - Non-PPS version for Bob Joyce; delete granule_list_file
C
      IMPLICIT NONE           ! Remove at own risk!

C ---------- Variable Declarations ----------

C
      include 'parameters.inc'

      ! Command line arguments
      integer     n_arguments
      character   input_file*109, cjobid*256
C     character   output_file*24
      character   oname*256, output_file*256, outpath_g*256
      integer*4   l_if, l_fullpath, l_on, l_outdir, iunit_t,
     &            iret
      integer*4   nsec0, nsec1, itime87, jstrt, jstop
C
C Arrays read in main program and passed along to extract-ssmis-tdrr:
C
      REAL*4      coeff_19v(NPIX/2)      !array 19V data in Kelvin
      REAL*4      coeff_19h(NPIX/2)      !array 19H data in Kelvin
      REAL*4      coeff_22v(NPIX/2)      !array 22V data in Kelvin
      REAL*4      coeff_37v(NPIX/2)      !array 37V data in Kelvin
      REAL*4      coeff_37h(NPIX/2)      !array 37H data in Kelvin
      REAL*4      coeff_91v(NPIX)        !array 91V data in Kelvin
      REAL*4      coeff_91h(NPIX)        !array 91h data in Kelvin
C
C Arrays read in main program and passed along to ingest-ssmis-tdrr:
C
      REAL*4      add_oce(161,7), add_lnd(161,7)
C
C     Function Declarations
      integer iargc

      ! Processing option variables
      logical      structure
      integer      tb2tc_option
      integer      input_option
      integer      sfcdata_option
      integer      output_option
      integer      frzhgt_option
      integer      bkgrd_option
      integer      bkgrd_clear_option

      ! Work arrays reserved for satellite input data
      real        Tb (NPIX, MAX_SCANS, NCHAN)  ! K
      real        lat(NPIX, MAX_SCANS)         ! [-90, +90]
      real        lon(NPIX, MAX_SCANS)         ! [-180, +180]
      integer     wentz_time(MAX_SCANS)        ! Wentz times (sec)
      integer*2   wentz_sfctype(NPIX, MAX_SCANS)

      ! For Petty background
c      real        hitheta(NPIX, MAX_SCANS)
      real        T_bkgrd_clear(NPIX, MAX_SCANS, NCHAN) ! K

      ! Arrays used for internal (std.) surface types and times;
      ! Tc is used for modified or corrected brightness temperatures.
      real        Tc(NPIX, MAX_SCANS, NCHAN) ! K
      integer*1   sfctype(NPIX, MAX_SCANS)
      integer*1   sfckind(NPIX, MAX_SCANS)
      integer*2   stdtime(MAX_SCANS, 6)      ! YYYY MM DD HH MM SS

      integer*4   istimeU(6), ietimeU(6)

      ! Internal variables
      real        T_bkgrd(NPIX, MAX_SCANS, NCHAN) ! K
      integer*2   pixel_status(NPIX, MAX_SCANS)
      integer*2   rain_status(NPIX, MAX_SCANS)
CC    character   satname*3   ! currently 'F16', 'F17', or 'F18'


      ! Retrieved variables
      real        frzheight(NPIX, MAX_SCANS)    ! km
      real        sfcrain(NPIX, MAX_SCANS)  ! mm/hr
      real        convect(NPIX, MAX_SCANS)  ! mm/hr
      real        quality(NPIX, MAX_SCANS)
      real        clw (NPIX, MAX_SCANS, NLYR)  ! kg/m^2
      real        rain(NPIX, MAX_SCANS, NLYR)  ! kg/m^2
      real        ciw (NPIX, MAX_SCANS, NLYR)
      real        ice (NPIX, MAX_SCANS, NLYR)
      real        Q1(NPIX, MAX_SCANS, 0:NLYR)

      ! Area averaged output variables
      integer     start_time(6)
      real        sum_sfcrain(720,1440)
      integer     sum_ncount(720,1440)
      integer     sum_nambig(720,1440)
      integer     sum_nrpix(720,1440)
      real        sum1_sfcrain(180,360)
      integer     sum1_ncount(180,360)
      integer     sum1_nambig(180,360)
      integer     sum1_nrpix(180,360)
C Following four arrays not used for 0.25-deg output.  Leave them
C here rather than deleting output-pathfinder option. (implicit none
C complains if these lines are deleted.)
      real        sum_intliq(360,720)
      real        sum_intice(360,720)
      real        sum_confdce(360,720)
      real        sum_convect(360,720)
C
      integer*1   grid_time(720,1440)
      integer*2   grid_sfcrain(720,1440)
      integer*1   grid_ncount(720,1440)
      integer*1   grid_nambig(720,1440)
      integer*1   grid_nrpix(720,1440)

      integer*1   grid1_time(180,360)
      integer*2   grid1_sfcrain(180,360)
      integer*1   grid1_ncount(180,360)
      integer*1   grid1_nambig(180,360)
      integer*1   grid1_nrpix(180,360)
 
      ! Housekeeping variables
      integer      nwork, i, ipos, jpos
      logical      more, do_debug
      integer      lin,pix,chan,icurrntlin
      integer      irec
      integer      nwrite
      logical      pad
      integer      start_line, nread, nfound, nrec, npad
      integer      first_line, last_line, istrt, istop
      character*8  bdate, edate
      character*6  btime, etime
      real         conv_obs(NPIX, MAX_SCANS)
      real         rain_obs(NPIX, MAX_SCANS)
      real         emisIndex(NPIX, MAX_SCANS, NEMIS)
      real         scatIndex(NPIX, MAX_SCANS, NSCAT)
      real         chanWgt(NPIX, MAX_SCANS, 7)

      ! Database variables
      integer      iostat, ierror
      integer*1    sfmask1(1440, 720)
      integer*1    sfmask2(1440, 720)
      integer*2    sstdata(0:143,0:90,12)
      real         flttw_tab(131, 131)
      integer*1    elev(4320,2160)

      ! Rainfall profile database variables
      integer      id,  k, n, ilat, ilon, nch

      integer      dbw_nprofiles(DB_WATER)
      integer      dbw_sfc_code(DB_WATER)
      real         dbw_lyrhgt(DB_WATER,NLYR)
      real         dbw_occur(DB_WATER,DBW_MXPROFILE)
      real         dbw_frzlevel(DB_WATER, DBW_MXPROFILE)
      real         dbw_sfcrain(DB_WATER,DBW_MXPROFILE)
      real         dbw_convect(DB_WATER,DBW_MXPROFILE)
      real         dbw_faconvmax(DB_WATER,DBW_MXPROFILE,NRING)
      real         dbw_faconvmean(DB_WATER,DBW_MXPROFILE,NRING)
      real         dbw_rain_cover(DB_WATER,DBW_MXPROFILE)
      real         dbw_conv_cover(DB_WATER,DBW_MXPROFILE)
      real         dbw_clw(DB_WATER,DBW_MXPROFILE,NLYR)
      real         dbw_rain(DB_WATER,DBW_MXPROFILE,NLYR)
      real         dbw_ciw(DB_WATER,DBW_MXPROFILE,NLYR)
      real         dbw_ice(DB_WATER,DBW_MXPROFILE,NLYR)
      real         dbw_Q1(DB_WATER,DBW_MXPROFILE,0:NLYR)
      real         dbw_Tb(DB_WATER,DBW_MXPROFILE,DB_NCHAN)
      real         dbw_Tbclr(DB_WATER,DBW_MXPROFILE,DB_NCHAN)
      real         dbw_Tb_cover(DB_WATER,DBW_MXPROFILE,DB_NCHAN)
      real         dbw_emisIndex(DB_WATER,DBW_MXPROFILE,NEMIS)
      real         dbw_scatIndex(DB_WATER,DBW_MXPROFILE,NSCAT)

      integer      dbl_nprofiles(DB_LAND)
      integer      dbl_sfc_code(DB_LAND)
      real         dbl_lyrhgt(DB_LAND,NLYR)
      integer      dbl_cstype(DB_LAND,DBL_MXPROFILE)
      real         dbl_occur(DB_LAND,DBL_MXPROFILE)
      real         dbl_sfcrain(DB_LAND,DBL_MXPROFILE)
      real         dbl_convect(DB_LAND,DBL_MXPROFILE)
      real         dbl_rain_cover(DB_LAND,DBL_MXPROFILE)
      real         dbl_conv_cover(DB_LAND,DBL_MXPROFILE)
      real         dbl_clw(DB_LAND,DBL_MXPROFILE,NLYR)
      real         dbl_rain(DB_LAND,DBL_MXPROFILE,NLYR)
      real         dbl_ciw(DB_LAND,DBL_MXPROFILE,NLYR)
      real         dbl_ice(DB_LAND,DBL_MXPROFILE,NLYR)
      real         dbl_Q1(DB_LAND,DBL_MXPROFILE,0:NLYR)
      real         dbl_Tb(DB_LAND,DBL_MXPROFILE,DB_NCHAN)
      real         dbl_Tb_cover(DB_LAND,DBL_MXPROFILE,DB_NCHAN)

      integer      dbc_nprofiles(DB_LAND)
      integer      dbc_sfc_code(DB_LAND)
      real         dbc_lyrhgt(DB_LAND,NLYR)
      integer      dbc_cstype(DB_LAND,DBL_MXPROFILE)
      real         dbc_occur(DB_LAND,DBL_MXPROFILE)
      real         dbc_sfcrain(DB_LAND,DBL_MXPROFILE)
      real         dbc_convect(DB_LAND,DBL_MXPROFILE)
      real         dbc_rain_cover(DB_LAND,DBL_MXPROFILE)
      real         dbc_conv_cover(DB_LAND,DBL_MXPROFILE)
      real         dbc_clw(DB_LAND,DBL_MXPROFILE,NLYR)
      real         dbc_rain(DB_LAND,DBL_MXPROFILE,NLYR)
      real         dbc_ciw(DB_LAND,DBL_MXPROFILE,NLYR)
      real         dbc_ice(DB_LAND,DBL_MXPROFILE,NLYR)
      real         dbc_Q1(DB_LAND,DBL_MXPROFILE,0:NLYR)
      real         dbc_Tb(DB_LAND,DBL_MXPROFILE,DB_NCHAN)
      real         dbc_Tb_cover(DB_LAND,DBL_MXPROFILE,DB_NCHAN)

      ! Static variables: Data Bases
      logical      first_time
      save         first_time
      save         dbw_nprofiles, dbw_sfc_code, dbw_lyrhgt,
     +             dbw_occur, dbw_frzlevel, dbw_sfcrain,
     +             dbw_convect, dbw_faconvmax, dbw_faconvmean,
     +             dbw_rain_cover, dbw_conv_cover, dbw_clw, dbw_rain,
     +             dbw_ciw, dbw_ice, dbw_Q1, dbw_Tb, dbw_Tbclr,
     +             dbw_Tb_cover, dbw_emisIndex, dbw_scatIndex
      save         dbl_nprofiles, dbl_sfc_code, dbl_lyrhgt, dbl_cstype,
     +             dbl_occur, dbl_sfcrain, dbl_convect,
     +             dbl_rain_cover, dbl_conv_cover, dbl_clw, dbl_rain,
     +             dbl_ciw, dbl_ice, dbl_Q1, dbl_Tb, dbl_Tb_cover
      save         dbc_nprofiles, dbc_sfc_code, dbc_lyrhgt, dbc_cstype,
     +             dbc_occur, dbc_sfcrain, dbc_convect,
     +             dbc_rain_cover, dbc_conv_cover, dbc_clw, dbc_rain,
     +             dbc_ciw, dbc_ice, dbc_Q1, dbc_Tb, dbc_Tb_cover
      save         sfmask1, sfmask2, sstdata, flttw_tab, elev

      data         first_time /.TRUE./

      !=================================================================
      !  added variables for extract_ssmis_TDRR
      !=================================================================
      
      integer*2       syear	      		!starting year
      integer*2       eyear       		!ending year 
      integer*2       sjday	      		!starting julian day of the year
      integer*2       ejday     		!ending julian day 
      integer*2	      ahrs                      !Starting hour
      integer*2	      amns                      !Starting minute
      integer*4	      jdate(MAX_SCANS)		!packed Julian date for each scan (YYYYDDD)
      real*4          atime(MAX_SCANS) 		!B-Scan time for each scan starting
        			      		!from current day in seconds
      integer*8       itimesec
      integer*4       ijday, iyr
 
      real*4	      a19v(NPIX/2,MAX_SCANS)      !A-scan 19V data in Kelvin
      real*4	      a19h(NPIX/2,MAX_SCANS)      !A-scan 19H data in Kelvin
      real*4	      a22v(NPIX/2,MAX_SCANS)      !A-scan 22V data in Kelvin
      real*4	      a37v(NPIX/2,MAX_SCANS)      !A-scan 37V data in Kelvin
      real*4	      a37h(NPIX/2,MAX_SCANS)      !A-scan 37H data in Kelvin

      real*4	      a91v(NPIX,MAX_SCANS)     	!A-scan and B-scan 91V data in Kelvin
      real*4	      a91h(NPIX,MAX_SCANS)     	!A-scan and B-scan 91h data in Kelvin

      integer*2	      sfc_img(NPIX,MAX_SCANS)     !sfc tag for imaging
      real*4	      alat1(NPIX,MAX_SCANS)     !latitude in degrees of 91
      real*4	      alon1(NPIX,MAX_SCANS)     !longitude in degrees of 91

      integer*2	      sfc_env(NPIX/2,MAX_SCANS)   !sfc tag for environmental
      real*4	      alat2(NPIX/2,MAX_SCANS)     !latitude in degrees of 37
      real*4	      alon2(NPIX/2,MAX_SCANS)     !longitude in degrees of 37
      real*4	      alat3(NPIX/2,MAX_SCANS)     !latitude in degrees of 19, 22
      real*4	      alon3(NPIX/2,MAX_SCANS)     !longitude in degrees of 19, 22
      real*4	      orig_lat(NPIX,MAX_SCANS,3) !latitude in degrees of all channels
      real*4	      orig_lon(NPIX,MAX_SCANS,3) !longitude in degrees of all channels

      integer*4       aline           		!scanlines in this file
      
      integer*4	      start_record	!to keep track of scan line

c    Variables for output

      real*4 xlat, xlon, xrain, tsec, xhr, xmn
      integer irain, ipxstat, irnstat, ihr, imn, isc
      
      !=================================================================
      !  HDF output file related variables
      !=================================================================
      character*42    hdf_outfile
      real	      hdf_lon(NPIX,MAX_SCANS)
      real	      hdf_lat(NPIX,MAX_SCANS)      
      real	      hdf_rain(NPIX,MAX_SCANS)      
      integer*2	      hdf_time(6,MAX_SCANS)
      character*3     sat_name  ! satellite name, F16, F17, F18
      character*3     sat_name_lc  ! satellite name, f16, f17, f18
      integer         fname_start
      character*256   fname

      integer ii, jj

      ! ================================================================
      ! Initialize returned variable to be undefined
      ! ================================================================
      


      do lin=1,MAX_SCANS
        
	hdf_time(1,lin)=0
        hdf_time(2,lin)=0
        hdf_time(3,lin)=0
        hdf_time(4,lin)=0
        hdf_time(5,lin)=0
        hdf_time(6,lin)=0
	
        do pix=1, NPIX
          hdf_lon(pix,lin)=0.0
          hdf_lat(pix,lin)=0.0
          hdf_rain(pix,lin)=0.0      
        enddo
      
      enddo	 

C     write (*,*) 'Modified SSM/I GPROF V7 for SSMIS'
 
C ---------- Set processing options --------

      input_option   = 3     ! 1=ascii; 2=gdmp; 3=tdr; 4=hdf
      tb2tc_option   = 2     ! 1=copy ; 2=interpolate
      sfcdata_option = 3     ! 1=Wentz_2_std; 2=Std. 0.25deg. database; 3=Petty
      frzhgt_option  = 3     ! 1=fixed; 2=Climatology; 3=Wilheit 19/22 GHz
      bkgrd_option   = 1     ! 0=compute no backgrd; 1=compute backgrd
      bkgrd_clear_option = 1 ! 1=Petty clear backgrd; 2="clearest" clear backgrd
      output_option  = 9     ! 1=rain; 2=debug; 3=sfc; 4=structure;
                             ! 5=0.5-deg gridded; 6=0.25-deg gridded; 7=record;
                             ! 8=1-deg gridded


C ---------- Initialization ----------


      ! Set variable "structure" to .TRUE. if structure is needed
      !structure = .FALSE.
      structure = .TRUE.


C  Read databases into memory the first time this subroutine is called.
 
      if ( first_time ) then
         first_time = .FALSE.
         if (do_debug) write(*,*) 'Reading data bases into memory'
         call read_dbase(cjobid, sfmask1, sfmask2, sstdata,
     &     flttw_tab, dbw_nprofiles, dbw_sfc_code, dbw_lyrhgt,
     &     dbw_occur, dbw_frzlevel, dbw_sfcrain, dbw_convect,
     &     dbw_rain_cover, dbw_conv_cover, dbw_faconvmax,
     &     dbw_faconvmean,
     &     dbw_clw, dbw_rain, dbw_ciw, dbw_ice, dbw_Q1, dbw_Tb,
     &     dbw_Tbclr, dbw_Tb_cover, elev, dbl_nprofiles,
     &     dbl_sfc_code, dbl_lyrhgt, dbl_cstype, dbl_occur,
     &     dbl_sfcrain, dbl_convect, dbl_rain_cover, dbl_conv_cover,
     &     dbl_clw, dbl_rain, dbl_ciw, dbl_ice, dbl_Q1,
     &     dbl_Tb, dbl_Tb_cover, dbc_nprofiles,
     &     dbc_sfc_code, dbc_lyrhgt, dbc_cstype, dbc_occur,
     &     dbc_sfcrain, dbc_convect, dbc_rain_cover, dbc_conv_cover,
     &     dbc_clw, dbc_rain, dbc_ciw, dbc_ice, dbc_Q1,
     &     dbc_Tb, dbc_Tb_cover)
      endif
 
      ! ================================================================
      !  Extract out all data from input file (SSMIS)
      ! ================================================================

      call extract_ssmis_tdrr(cjobid, input_file, syear, sjday,
     &     eyear, ejday, jdate, atime, sat_name,
     &     a19v, a19h, a22v, a37v, a37h, a91v, a91h,
     &     alat1, alon1, alat2, alon2, alat3, alon3,
     &     aline,ahrs,amns,sfc_img,sfc_env,coeff_19v,coeff_19h,
     &     coeff_22v,coeff_37v,coeff_37h,coeff_91v,coeff_91h,do_debug,
     &     iret)
C
      IF (iret .NE. 0) RETURN
 
      irec=0

C ---------- Main Retrieval Loop ----------
      if (do_debug) then
       write(*,*) 'Starting main retrieval loop...'
      endif
 
C
C  npad refers to the number of pad lines to expect at the beginning
C  and end of an orbit, whereas NBUFF refers to the number of buffer
C  lines for the interior-orbit segments of NCORE lines each.
C
      npad = 0

      !Fill all global variables with default values

      call init_arrays(pixel_status, rain_status, frzheight,
     &	     sfcrain, convect, quality, structure, 
     &	     clw, rain, ciw, ice, Q1)

C EJN: Call select_unique to determine the range of scan lines that
C      contain unique data, since the CLASS SSMIS TDR files contain
C      overlap at the beginning and end.

      call select_unique(cjobid,iunit_t,aline,jdate,atime,istrt,istop,
     &                   do_debug)
C
C EJN: If istrt = istop (even if not zero), meaning only one unique
C scan was found, skip this file and move on to the next one in the
C list.
C

c     write (6,'('' istrt, istop = '',2i9)') istrt,istop

      IF (istrt .EQ. istop) RETURN
C
C Further modify the values of istrt, istop if necessary to conform to
C the user-specified time window, i.e. exclude any scans outside the
C requested time range.
C
      DO lin = istrt, istop
         CALL CONVTIME(jdate(lin), atime(lin), itime87)
         IF ( itime87 .GE. nsec0 .AND.
     &                itime87 .LE. nsec1 ) THEN
            jstrt = lin
            GO TO 55
         ENDIF
      END DO

c     write (6,'(''itime87,nsec0,nsec1 ='',3i13)') itime87,nsec0,nsec1

C
C If the code reaches this line, the entire file was either entirely
C before or entirely after the specified time range of the processing
C window.  Skip this file and move on to the next one in the list.
C
      RETURN
 
   55 CONTINUE
C
C Now search backwards from the end of the file to determine the last
C scan of the input file that falls within the requested time range.
C Since jstrt has been set above, this file is guaranteed to have some
C data within the requested time range, and it is necessary to search
C backwards only up until jstrt, not istrt.
C
      DO lin = istop, jstrt, -1
         CALL CONVTIME(jdate(lin), atime(lin), itime87)
         IF ( itime87 .LE. nsec1 .AND.
     &               itime87 .GE. nsec0 ) THEN
            jstop = lin
            GO TO 56
         ENDIF
      END DO
   56 CONTINUE
C
C EJN: Instruct ingest_ssmis_tdrr to process the scan range [jstrt,
C      jstop].
C
      start_line = jstrt
      nread = jstop - jstrt + 1
cejn debug
c     write(*,*) 'start line = ', jstrt,'; jstop = ', jstop

      !==============================================================
      ! call ingest routine
      !==============================================================
      call ingest_ssmis_tdrr(start_line, nread, nfound, 
     & 	     Tb, orig_lat, orig_lon, stdtime, 
     &	     syear, sjday, eyear, ejday, atime,
     &	     a19v, a19h, a22v, a37v, a37h, a91v, a91h,  
     &	     alat1, alon1, alat2, alon2, alat3, alon3, 
     &       sfc_img, sfc_env, aline, add_oce, add_lnd, cjobid,
     &       do_debug)
C    &       aline, irec)
cejn debug
c     do lin = 1, aline
c     do pix = 1, NPIX
c        write(514,988) lin, pix, (Tb(pix,lin,chan), chan=1,7)
c 988    format(i4,i4,7f9.2)
c     end do
c     end do
cend debug

C	write(*,*) 'finish ingest TDRR', aline

C	write(*,*) 'nfound', nfound
C	write(*,*) 'nread',  nread

C-----------------------------------------------------------------------
C 10/12/2011 EJN - This routine is no longer used.
C
      !================================================================
      ! SSMIS -> SSMI channels
      !================================================================
 
cejn  call convert_ssmis_91GHz(start_line,nfound,aline,Tb,
c
cejn  Pass in orig_lat, orig_lon
C     call convert_ssmis_91GHz(nfound,aline,Tb,
C    &                         orig_lat,orig_lon,sat_name) 
C-----------------------------------------------------------------------

      !==============================================================
      ! Call routine to interpolate SSMIS channels to common grid
      !==============================================================
      call geolocate_ssmis(Tb, orig_lat, orig_lon, aline, lat, lon)

      if (nfound .LE. nread) then
         nwork = min(nfound, MAX_SCANS)
         nwrite = nwork-npad

        ! Fill empty lines with missing values. 
         first_line = nwrite+1
         last_line = MAX_SCANS
               
C
C  The following two solutions give the same result.  As a group,
C  we should ultimately determine which of the two we prefer.
C
C  Solution 1: Do not call clear_scans if there is a pad.
C
C                 if ( .NOT. pad ) call clear_scans(nfound+1, nread, Tb,
C    &                   lat, lon, wentz_time, wentz_sfctype, stdtime,
C    &                   sfctype, sfckind)
C
C  Solution 2: Modify the argument for the first line to be cleared,
C              to account for a possible pad.
C
         call clear_scans(nfound+npad+1, nread, Tb, lat, lon,
     &                    wentz_time, wentz_sfctype, stdtime,
     &                    sfctype, sfckind)
      else
         nwork  = MAX_SCANS
         nwrite = MAX_SCANS
      end if
	
C	write(*,*) 'nwork',  nwork
C	write(*,*) 'nwrite', nwrite
 

      ! Deconvolve temperatures to fill high resolution
      ! array.  In this code, low-res temperatures are merely
      ! copied.

      if ( tb2tc_option .eq. 1 ) then
         call Tb2Tc_copy(nwork, Tb, Tc)
      else if ( tb2tc_option .eq. 2 ) then
         call Tb2Tc_intplte(nwork, Tb, Tc)
      endif
 
      ! Convert Wentz seconds into YYYYMMDD HHMMSS format
      if (input_option .eq. 2)
     &   call convtime_wentz(nwork, wentz_time, stdtime)

      ! Calculate emission and scattering indices for the ocean
      ! database profiles.
      call dbw_emis_scat_Index(dbw_nprofiles, dbw_Tb, dbw_Tbclr, 
     &  dbw_emisIndex, dbw_scatIndex)  

       ! bindmp/ascii use Wentz sfc.  Get standard sfc-type/kind
      if ( sfcdata_option .eq. 1) then
         call surface_wentz(nwork, wentz_sfctype,
     &             sfctype, sfckind)
      else if ( sfcdata_option .eq. 2) then
         call surface_db93(nwork, sfmask1, sfmask2, lat, lon,
     &             sfctype, sfckind)
      else if ( sfcdata_option .eq. 3) then
cejn     call surface_db93_petty(start_line, nfound,
CC       call surface_db93_petty(nfound, lsflag,
CC   &             sfmask2, lat, lon, sfctype, sfckind)
         call surface_db93_petty(cjobid, nfound, sfmask2,
     &                           lat, lon, sfctype, sfckind, do_debug)
      end if

      ! Perform generic quality control

      call qualctrl(nwork, Tb, Tc, lat, lon, stdtime,
     &	      sat_name, sfctype, pixel_status)

      ! Compute auxiliary parameters.

      if ( frzhgt_option .eq. 1) then
      	 call frzhgt_fixed(nwork, pixel_status, frzheight)
      else if ( frzhgt_option .eq. 2) then
      	 call frzhgt_climate(nwork, lat, lon, stdtime,
     &	     sstdata, pixel_status, frzheight)
      else if ( frzhgt_option .eq. 3) then
      	 call frzhgt_ttw(nwork, Tc, flttw_tab, sstdata,
     &	     pixel_status, lat, lon, stdtime, sfctype,
     &	     frzheight)
      endif
 
      ! Rainfall screening routines.  Each surface type is
      ! handled independently.  Other surface types are
      ! not considered.

      call screen_land(nwork, Tc, sfctype, sfckind, 
     &	    stdtime, pixel_status, rain_status, lat, lon, elev)
      call screen_ocean(nwork, Tc, sfctype, sfckind, frzheight,
     &	    pixel_status, rain_status)
      call screen_coast(nwork, Tc, sfctype, 
     &	    pixel_status, rain_status)
      call screen_ice(nwork, Tc, sfctype, sfckind, 
     &	    pixel_status, rain_status)
	
      ! Background Tb - rainfall routines sometimes need
      ! to know the background Tb (where it is not raining).

      if ( bkgrd_option .eq. 1 ) then
         call bkgrd_fill(nwork, Tc, sfctype, pixel_status,
     &	    rain_status, T_bkgrd)
      endif

      ! Compute Petty Clear-air radiances
      if( bkgrd_clear_option .eq. 1) then
        call bkgrd_clear_ocean (nwork, lon, lat, stdtime,
     &    pixel_status, sfctype, 1, sstdata,
     &    Tc, T_bkgrd_clear)
        call T_bkgrd_ocean_ctrl(nwork, pixel_status, 
     &            sfctype, T_bkgrd_clear, lat, lon)
      endif
 
      ! Compute emission and scattering indeces over ocean
      call emis_scat_index(nwork, Tc, T_bkgrd, 
     &  bkgrd_clear_option, T_bkgrd_clear, pixel_status, sfctype,
     &  emisIndex, scatIndex)

      ! Compute convective fraction over ocean
      call comp_frac(nwork, Tc, T_bkgrd, pixel_status,  
     &  sfctype, conv_obs, rain_obs, emisIndex, scatIndex)

      ! Rainfall retrieval.
      call rain_ocean(nwork, sfctype, sfckind, frzheight, 
     &      pixel_status, rain_status, dbw_nprofiles, 
     &      dbw_sfc_code, dbw_occur, dbw_frzlevel, dbw_rain_cover,
     &      dbw_sfcrain, dbw_convect, dbw_conv_cover, dbw_faconvmax,
     &      dbw_faconvmean, dbw_clw, dbw_rain, dbw_ciw,
     &      dbw_ice, dbw_Q1, dbw_Tb_cover, dbw_emisIndex,  
     &      dbw_scatIndex, conv_obs, rain_obs, emisIndex, scatIndex,  
     &      sfcrain, convect, quality, structure, clw, rain, ciw, ice, 
     &      Q1) 

      call rain_land(nwork, Tc, sfctype, pixel_status,
     &      rain_status, dbl_nprofiles, dbl_sfc_code,
     &      dbl_occur, dbl_sfcrain, dbl_convect,
     &      dbl_clw, dbl_rain, dbl_ciw, dbl_ice, dbl_Q1,
     &      dbl_Tb, sfcrain, convect, quality, structure,
     &      clw, rain, ciw, ice, Q1, dbl_cstype)

      call rain_coast(nwork, Tc, sfctype, sfckind, frzheight, 
     &      pixel_status, rain_status, dbc_nprofiles, 
     &      dbc_sfc_code, dbc_cstype, dbc_occur, 
     &      dbc_sfcrain, dbc_convect, dbc_clw, dbc_rain, dbc_ciw,  
     &      dbc_ice, dbc_Q1, dbc_Tb, dbc_Tb_cover, sfcrain, 
     &      convect, quality, structure, clw, rain, ciw, ice, Q1)
           
      !==============================================================
      ! assign to output varaibles  
      !==============================================================
       do lin=1, nwork
         
         do pix=1,6
            hdf_time(pix,lin)=stdtime(lin, pix)
         enddo
         
         do pix=1, NPIX
            
            !=========================================================
            ! assign to output varaibles 
            !=========================================================
            
            hdf_lon(pix, lin ) = lon(pix, lin) 
            hdf_lat(pix, lin ) = lat(pix, lin) 
            hdf_rain(pix,lin ) = sfcrain(pix, lin) 
        	    
         enddo

      enddo
 
      !==============================================================
      ! Output to hdf-eos swath format file 
      !==============================================================

      ! Write retrieved parameters to output file.
      ! Only write lines 1 through nwork.  Ordinarily this will be
      ! the contents of the entire core area (i.e. nwork = NCORE),
      ! but on the last iteration of the main retrieval loop (i.e.
      ! nwork < NCORE) this will only be the portion of the core area
      ! that contains data.

      if ( output_option .eq. 1 ) then
         call output_rain(nwrite, lat, lon, sfcrain)
      else if ( output_option .eq. 2 ) then
         call output_debug(nwrite, lat, lon, Tb, Tc, stdtime,
     &        sfctype, sfckind, frzheight, pixel_status,
     &        rain_status, sfcrain,
     &        quality)
cejn &        quality, dbw_lyrhgt, clw, rain, ciw, ice)
      else if ( output_option .eq. 3 ) then
         call output_surface(nwrite, lat, lon, stdtime,
     &        pixel_status, rain_status, sfcrain, quality)
      else if ( output_option .eq. 4 ) then
         call output_structure(nwrite, lat, lon, stdtime,
     &        pixel_status, rain_status, sfctype, sfcrain, convect,
     &        quality, dbw_lyrhgt, clw, rain, ciw, ice, Q1)
      else if ( output_option .eq. 5 ) then
         call output_pathfinder(nwrite, lat, lon,
     &        stdtime, pixel_status, rain_status, sfcrain,
     &        convect, quality, dbw_lyrhgt, clw, rain, ciw,
     &        ice, start_time, sum_sfcrain, sum_ncount,
     &        sum_nambig, sum_intliq, sum_intice,
     &        sum_confdce, sum_convect, sum_nrpix, grid_time)
      else if ( output_option .eq. 6 ) then
         ipos = 1
         more = .FALSE.
         call output_quarterdeg(nwrite, ipos, more, lat, lon,
     &        stdtime, pixel_status, rain_status, sfcrain,
     &        start_time, sum_sfcrain, sum_ncount, sum_nambig,
     &        sum_nrpix, grid_time)
      else if ( output_option .eq. 7 ) then
c     	 call output_surface_hdf(hdf_outfile, aline, 
c    &        hdf_time, hdf_lon, hdf_lat, hdf_rain)
      else if ( output_option .eq. 8 ) then
         ipos = 1
         more = .FALSE.
         call output_1deg(nwrite, ipos, more, lat, lon,
     &        stdtime, pixel_status, rain_status, sfcrain,
     &        start_time, sum1_sfcrain, sum1_ncount, sum1_nambig,
     &        sum1_nrpix, grid1_time)
      else if ( output_option .eq. 9 ) then
       continue
      endif
 
C ---------- Scale output and write file ----------

      ! Clean up and output area averaged output variables

c NOTE: stdtime operates on [1,nwork] because ingest-ssmis-tdrr.f
c reassigned [istrt,istop] to [1,nwork] when loading arrays.
      if (output_option .eq. 6 .or. output_option .eq. 8  .or.
     &                              output_option .eq. 9) then
 
        if ( output_option .eq. 6 ) then
      continue
        else if ( output_option .eq. 8 ) then
      continue
        else if ( output_option .eq. 9 ) then

      do lin = 1, MAX_SCANS
 
c   Lets adjust this to
         icurrntlin = lin + istrt - 1
         itimesec = atime(icurrntlin)
         ijday    = jdate(icurrntlin)
         iyr      = ijday/1000
         ijday    = ijday - iyr*1000
 
         do pix = 1, NPIX

            ! skip to end if pixel_status < 0; however, allow -21
            ! to pass through, as set at end of rain-land-noaa.f.
ccc         if ( pixel_status(pix,lin) .lt. 0 .AND.
ccc  &           pixel_status(pix,lin) .ne. -21) goto 10

            ! if sfcrain = -999., then also skip to end; this
            ! will also eliminate any pixels whose pixel_status was set
            ! to -21 in qualctrl-v1 due to invalid sfctype < 0.

            ! Note that rain-ctrl set some sfcrain to -999. instead
            ! of MISS_FLT (= -9999.9).  The test below is designed to
            ! catch both of these possible values.
ccc         if ( sfcrain(pix,lin) .LT. -998.) goto 10

ccc         if ( ABS(sfcrain(pix,lin)).gt.0 )
ccc  $         sum_nrpix(ilat,ilon) = sum_nrpix(ilat,ilon) + 1

ccc         if ((rain_status(pix,lin) .gt.   0) .or.
ccc  $          (rain_status(pix,lin) .eq. -31))
ccc  $         sum_nambig(ilat,ilon) = sum_nambig(ilat,ilon) + 1

    ! sfcrain can be negative where a pixel is ambiguous, with
    ! rain_status = 13 or 14, so take absolute value when adding.
ccc         if ( rain_status(pix,lin) .ge. 0 ) then
ccc           sum_sfcrain(ilat,ilon) = sum_sfcrain(ilat,ilon) +
ccc  $             ABS(sfcrain(pix,lin))
ccc         endif

  10     continue
 
         xlat  = lat(pix,lin) + 90.0
         ilat  = xlat*100
         xlon  = lon(pix,lin)
         if (xlon.lt.0) xlon = 360.0 + xlon
         ilon  = xlon*100
         if (sfcrain(pix,lin).lt.0) then
          irain = -9999
         else
          irain = sfcrain(pix,lin)*100
         endif
         ipxstat = pixel_status(pix,lin)
         irnstat = rain_status(pix,lin)
         xrain   = sfcrain(pix,lin)

         tsec = itimesec
         xhr  = tsec/3600.0
         ihr  = xhr
         xmn  = (xhr-ihr)*60.0
         imn  = xmn
         isc  = (xmn-imn)*60.0

         if (itimesec.ge.0.and.ilat.ge.0.and.ilat.le.18000.and.
     &                         ilon.ge.0.and.ilon.le.36000) then
c         write(95,'(2i7,i8,i6,i6,2i4)') ilat,ilon,ijday,itimesec,irain,
c    &                                  ipxstat,irnstat
c23456789012345678901234567890123456789012345678901234567890123456789012
          write(95,'(f10.3,f10.3,f10.2,6i10)') xlat,xlon,xrain,irnstat,
     &                           iyr, ijday, ihr, imn, pix
         endif
         end do
      end do
 
        endif

      endif
C
      RETURN
C
      END

C------------------------------------------------------------------
C                     Housekeeping subroutines
C------------------------------------------------------------------


C ---------- Subroutine clear_scans ----------------

      ! Fill lines first_line to last_line (inclusive) of arrays with
      ! missing values.
      subroutine clear_scans(first_line, last_line, Tb, lat, lon,
     &      wentz_time, wentz_sfctype, stdtime, sfctype, sfckind)
      implicit none
      include 'parameters.inc'

      integer     first_line, last_line
      real        Tb(NPIX, MAX_SCANS, NCHAN)
      real        lat(NPIX, MAX_SCANS)
      real        lon(NPIX, MAX_SCANS)
      integer     wentz_time(MAX_SCANS)
      integer*2   wentz_sfctype(NPIX, MAX_SCANS)
      integer*2   stdtime(MAX_SCANS, 6)   ! YYYY MM DD HH MM SS
      integer*1   sfctype(NPIX, MAX_SCANS)
      integer*1   sfckind(NPIX, MAX_SCANS)


      integer     chan, lin, pix
      integer     i

      do lin = first_line, last_line
            do pix = 1, NPIX
                  do chan = 1, NCHAN
                        Tb(pix, lin, chan) = -999.0
                  end do

                  lat(pix, lin) = -999.0
                  lon(pix, lin) = -999.0

                  wentz_sfctype(pix, lin) = -1

                  sfctype(pix, lin) = -1
                  sfckind(pix, lin) = -1

            end do

            do i = 1, 6
               stdtime(lin,i) = -999
            end do

            wentz_time(lin) = -999

      end do

      return
      end
