      subroutine surface_wentz(nwork, wentz_sfctype, sfctype, sfckind)
      implicit none
      include 'parameters.inc'

      integer     nwork
      integer*2   wentz_sfctype(NPIX, MAX_SCANS)
      integer*1   sfctype(NPIX, MAX_SCANS)
      integer*1   sfckind(NPIX, MAX_SCANS)
      integer*2   iwork(NPIX, MAX_SCANS)

      integer     lin, pix, Nx, i, j

c     sfctype has one of the following values:
c             0 = land
c             1 = land w. vegetation cover ! does not occur in NRT files
c             3 = ice                      ! does not occur in NRT files
c             4 = possible (pack) ice
c             5 = ocean
c             6 = coast
c             7 = coast next to ice

      ! Assign wentz_sfctype to Gprof sfctype & sfckind

      do lin = 1, nwork
         do pix = 1, NPIX
            if ( wentz_sfctype(pix,lin) .eq. 0 ) then
              sfctype(pix,lin) = 1
              sfckind(pix,lin) = -1
            elseif ( wentz_sfctype(pix,lin) .eq. 1 ) then
              sfctype(pix,lin) = 1
              sfckind(pix,lin) = 11
            elseif ( wentz_sfctype(pix,lin) .eq. 3 ) then
              sfctype(pix,lin) = 1
              sfckind(pix,lin) = 13
            elseif ( wentz_sfctype(pix,lin) .eq. 4 ) then
              sfctype(pix,lin) = 0
              sfckind(pix,lin) = 04
            elseif ( wentz_sfctype(pix,lin) .eq. 5 ) then
              sfctype(pix,lin) = 0
              sfckind(pix,lin) = -1
            elseif ( wentz_sfctype(pix,lin) .eq. 6 ) then
              sfctype(pix,lin) = 2
              sfckind(pix,lin) = -1
            elseif ( wentz_sfctype(pix,lin) .eq. 7 ) then
              sfctype(pix,lin) = 2
              sfckind(pix,lin) = 27
            else
              sfctype(pix,lin) = 3
              sfckind(pix,lin) = -1
            end if
         end do
      end do

      ! Thicken the coastline by setting all pixels that border
      ! a coastline pixel to coastline.  Begin by copying sfc
      ! into temporary array

      Nx = 2

      do lin = 1, nwork
         do pix = 1, NPIX
            iwork(pix,lin) = sfctype(pix,lin)
         end do
      end do

      do lin = 1, nwork
         do pix = 1, NPIX

            ! if pixel is already coast, skip
            if (iwork(pix, lin) .eq. 2) go to 10

            ! otherwise check neighboring NxN pixels
            do  j = lin-Nx, lin+Nx
               do  i = pix-Nx, pix+Nx
                  if ( j .lt. 1 ) go to 30
                  if ( j .gt. nwork )  go to 30
                  if ( i .lt. 1 ) go to 30
                  if ( i .gt. NPIX)  go to 30
                  if (iwork(i,j) .eq. 2) then
                     sfctype(pix,lin) = 2
                     sfckind(pix,lin) = sfckind(i,j)
                     go to 10
                  endif
  30           end do
            end do
c          write(*,*)sfctype(pix,lin),sfckind(pix,lin),pix,lin
  10     end do
      end do

      return
      end
